@@ -117,7 +117,7 @@ public class MainWindow {
 		this.db = db;
 
 		Mono.Posix.Catalog.Init ("f-spot", FSpot.Defines.LOCALE_DIR);
-		Glade.XML gui = Glade.XML.FromAssembly ("f-spot.glade", "main_window", null);
+		Glade.XML gui = Glade.XML.FromAssembly ("f-spot.glade", "main_window", "");
 		gui.Autoconnect (this);
 
 		slide_delay = new FSpot.Delay (new GLib.IdleHandler (SlideShow));
@@ -419,9 +419,13 @@ public class MainWindow {
 			if (t.Icon == null) {
 				if (icon == null) {
 					// FIXME this needs a lot more work.
-					Pixbuf tmp = PixbufUtils.LoadAtMaxSize (query.Photos[num].DefaultVersionPath, 128, 128);
-					icon = PixbufUtils.TagIconFromPixbuf (tmp);
-					tmp.Dispose ();
+					try {
+						Pixbuf tmp = PixbufUtils.LoadAtMaxSize (query.Photos[num].DefaultVersionPath, 128, 128);
+						icon = PixbufUtils.TagIconFromPixbuf (tmp);
+						tmp.Dispose ();
+					} catch {
+						icon = null;
+					}
 				}
 				
 				t.Icon = icon;
