@@ -8,22 +8,22 @@ public class Driver {
 	public static void Main (string [] args)
 	{
 		Application.Init ();
-		Program program = new Program ("F-Spot", "0.0", Modules.UI, args);
+		Program program = new Program (FSpot.Defines.PACKAGE, FSpot.Defines.VERSION, Modules.UI, args);
 
+		Gnome.Vfs.Vfs.Initialize ();
 		StockIcons.Initialize ();
 
 		// FIXME: Error checking is non-existant here...
 
-		string home_directory = FSpot.Global.HomeDirectory;
 		string base_directory = FSpot.Global.BaseDirectory;
 		if (! File.Exists (base_directory))
 			Directory.CreateDirectory (base_directory);
 
 		Db db = new Db (Path.Combine (base_directory, "photos.db"), true);
 		
-		Gtk.Window.DefaultIconList = new Gdk.Pixbuf [] {PixbufUtils.LoadFromAssembly ("f-spot-camera.png")};
+		Gtk.Window.DefaultIconList = new Gdk.Pixbuf [] {PixbufUtils.LoadFromAssembly ("f-spot-logo.png")};
 
-		MainWindow main_window = new MainWindow (db);
+		new MainWindow (db);
 		
 		ParseCommands (args);
 
